
/*
*	TITLE		Queued serial drivers for FreeRTOS using dsPIC33 and PIC24
*					
*	VERSION:	0.2a (Beta)                           
*
*	DATE:		08-Oct-2011
*
*	AUTHOR:		Tom Lafleur  
*				lafleur@lafleur.us
*
*	COMMENTS:	You are free to use this source code for any non-commercial
*				use. Please do not make copies of this source code, modified
*				or un-modified, publicly available on the internet or
*				elsewhere without permission. Thanks.
*
*				Copyright 2005-2011 R.  . All rights are reserved.
*
********************************************************************************
*
*	CHANGE LOG:
*
*	DATE         REV  DESCRIPTION
*	-----------  ---  ----------------------------------------------------------
*	12-Jun-2009  0.1	TRL - Original code for N2K60 under FreeRTOS
*	01-Oct-2011	 0.2a	TRL - Added serial port 2, write function, error counters
*				 0.3	TRL - 
*
*
*	Notes:		1)	Tested with FreeRTOS ver 7.0.1 PIC24/33, N2k60 board
*				2)  Support for two serial ports, can easily be expanded for more ports
*				3)  Added Rx error counters to the data structures
*				4)	If using processors with Peripheral pin select, you must define
*					 pin's prior to using this driver 
*				5)  Based on FreeRTOS demo code and my 2007 robotics serial driver  
*
*	ToDo:		1)  Check if code is atomic and thread safe
*				2)  Make Rx error counters avilable global
*				3)  Make Tx use DMA if avilable, if so we will use ring buffers
*					 and give a full buffer to DMA system. Queue's are too slow.
*				4) 
*
* 	My Notes:
*		
*		
*		
*/

#ifndef SERIAL_COMMS_H
#define SERIAL_COMMS_H

typedef void * xComPortHandle;
//typedef xComPort * xComPortHandle;

typedef enum
{ 
	serCOM1, 
	serCOM2, 
	serCOM3, 
	serCOM4, 
	serCOM5, 
	serCOM6, 
	serCOM7, 
	serCOM8 
} eCOMPort;

typedef enum 
{ 
	serNO_PARITY, 
	serEVEN_PARITY, 
	serODD_PARITY 
} eParity;

typedef enum 
{ 
	serSTOP_1, 
	serSTOP_2 
} eStopBits;

typedef enum 
{ 
	serBITS_8, 
	serBITS_9 
} eDataBits;


/*-----------------------------------------------------------*/
xComPortHandle xSerialPortInit( eCOMPort ePort, unsigned long, eParity eWantedParity, eDataBits eWantedDataBits, eStopBits eWantedStopBits, unsigned portBASE_TYPE uxTxBufferLength, unsigned portBASE_TYPE uxRxBufferLength );
void vSerialPutString( xComPortHandle pxPort, const signed char * const pcString, unsigned short usStringLength );
signed portBASE_TYPE xSerialGetChar( xComPortHandle pxPort, signed char *pcRxedChar, portTickType xBlockTime );
signed portBASE_TYPE xSerialPutChar( xComPortHandle pxPort, signed char cOutChar, portTickType xBlockTime );
void vSerialClose( xComPortHandle xPort );

// These are NOT RTOS safe, use with care!

/* These functions are NOT RTOS safe, use with care */
void uart1_puts(char *str);
void uart1_putc(char c);
void uart1_put(char *str, int len);
void uart2_puts(char *str);
void uart2_putc(char c);
void uart2_put(char *str, int len);

#endif

